@@ -67,7 +67,7 @@ class MinumtiumPostgresAdapter(DatabaseAdapter):
         dbname = config.dbname
 
         if config.use_unix_socket:
-            create_engine(f"postgresql+pg8000://{username}:{password}@/{dbname}?unix_socket={config.host}")
+            return reate_engine(f"postgresql+pg8000://{username}:{password}@/{dbname}?unix_socket={config.host}")
 
         return create_engine(f"postgresql+pg8000://{username}:{password}@{host}:{port}/{dbname}")
 
